@@ -12,5 +12,5 @@ df = sns.load_dataset("anscombe")
 
 # Show the results of a linear regression within each dataset
 sns.lmplot(x="x", y="y", col="dataset", hue="dataset", data=df,
-           col_wrap=2, ci=None, palette="muted", size=4,
+           col_wrap=2, ci=None, palette="muted", height=4,
            scatter_kws={"s": 50, "alpha": 1})
