@@ -12,4 +12,4 @@ sns.set(style="darkgrid")
 tips = sns.load_dataset("tips")
 g = sns.FacetGrid(tips, row="sex", col="time", margin_titles=True)
 bins = np.linspace(0, 60, 13)
-g.map(plt.hist, "total_bill", color="steelblue", bins=bins, lw=0)
+g.map(plt.hist, "total_bill", color="steelblue", bins=bins)
