@@ -2,7 +2,7 @@
 Grouped violinplots with split violins
 ======================================
 
-_thumb: .5, .47
+_thumb: .43, .47
 """
 import seaborn as sns
 sns.set(style="whitegrid", palette="pastel", color_codes=True)
@@ -11,6 +11,8 @@ sns.set(style="whitegrid", palette="pastel", color_codes=True)
 tips = sns.load_dataset("tips")
 
 # Draw a nested violinplot and split the violins for easier comparison
-sns.violinplot(x="day", y="total_bill", hue="sex", data=tips, split=True,
-               inner="quart", palette={"Male": "b", "Female": "y"})
+sns.violinplot(x="day", y="total_bill", hue="smoker",
+               split=True, inner="quart",
+               palette={"Yes": "y", "No": "b"},
+               data=tips)
 sns.despine(left=True)
