@@ -4,12 +4,12 @@ Horizontal boxplot with observations
 
 _thumb: .7, .37
 """
-import numpy as np
 import seaborn as sns
 import matplotlib.pyplot as plt
+
 sns.set(style="ticks")
 
-# Initialize the figure
+# Initialize the figure with a logarithmic x axis
 f, ax = plt.subplots(figsize=(7, 6))
 ax.set_xscale("log")
 
@@ -18,14 +18,13 @@ planets = sns.load_dataset("planets")
 
 # Plot the orbital period with horizontal boxes
 sns.boxplot(x="distance", y="method", data=planets,
-            whis=np.inf, palette="vlag")
+            whis="range", palette="vlag")
 
 # Add in points to show each observation
 sns.swarmplot(x="distance", y="method", data=planets,
               size=2, color=".3", linewidth=0)
 
-
-# Make the quantitative axis logarithmic
+# Tweak the visual presentation
 ax.xaxis.grid(True)
 ax.set(ylabel="")
 sns.despine(trim=True, left=True)
