@@ -7,13 +7,13 @@ _thumb: .58, .5
 import seaborn as sns
 sns.set(style="darkgrid")
 
-# Load the example titanic dataset
+# Load the example Titanic dataset
 df = sns.load_dataset("titanic")
 
 # Make a custom palette with gendered colors
 pal = dict(male="#6495ED", female="#F08080")
 
-# Show the survival proability as a function of age and sex
+# Show the survival probability as a function of age and sex
 g = sns.lmplot(x="age", y="survived", col="sex", hue="sex", data=df,
-               palette=pal, y_jitter=.02, logistic=True)
+               palette=pal, y_jitter=.02, logistic=True, truncate=False)
 g.set(xlim=(0, 80), ylim=(-.05, 1.05))
