@@ -2,11 +2,10 @@
 Scatterplot with marginal ticks
 ===============================
 
-_thumb: .68, .32
+_thumb: .62, .39
 """
 import numpy as np
 import seaborn as sns
-import matplotlib.pyplot as plt
 sns.set(style="white", color_codes=True)
 
 # Generate a random bivariate dataset
@@ -16,6 +15,6 @@ cov = [(1, 0), (0, 2)]
 x, y = rs.multivariate_normal(mean, cov, 100).T
 
 # Use JointGrid directly to draw a custom plot
-grid = sns.JointGrid(x, y, space=0, height=6, ratio=50)
-grid.plot_joint(plt.scatter, color="g")
+grid = sns.JointGrid(x, y, space=0, height=6, ratio=20)
+grid.plot_joint(sns.scatterplot, color="g")
 grid.plot_marginals(sns.rugplot, height=1, color="g")
