@@ -10,6 +10,6 @@ sns.set(style="white")
 df = sns.load_dataset("iris")
 
 g = sns.PairGrid(df, diag_sharey=False)
-g.map_lower(sns.kdeplot)
 g.map_upper(sns.scatterplot)
-g.map_diag(sns.kdeplot, lw=3)
+g.map_lower(sns.kdeplot, colors="C0")
+g.map_diag(sns.kdeplot, lw=2)
