@@ -13,11 +13,11 @@ crashes = sns.load_dataset("car_crashes")
 # Make the PairGrid
 g = sns.PairGrid(crashes.sort_values("total", ascending=False),
                  x_vars=crashes.columns[:-3], y_vars=["abbrev"],
-                 size=10, aspect=.25)
+                 height=10, aspect=.25)
 
 # Draw a dot plot using the stripplot function
 g.map(sns.stripplot, size=10, orient="h",
-      palette="Reds_r", edgecolor="gray")
+      palette="ch:s=1,r=-.1,h=1_r", linewidth=1, edgecolor="w")
 
 # Use the same x axis limits on all columns and add better labels
 g.set(xlim=(0, 25), xlabel="Crashes", ylabel="")
