@@ -8,5 +8,7 @@ import seaborn as sns
 sns.set(style="darkgrid")
 
 tips = sns.load_dataset("tips")
-g = sns.jointplot("total_bill", "tip", data=tips, kind="reg",
-                  xlim=(0, 60), ylim=(0, 12), color="m", height=7)
+g = sns.jointplot("total_bill", "tip", data=tips,
+                  kind="reg", truncate=False,
+                  xlim=(0, 60), ylim=(0, 12),
+                  color="m", height=7)
