@@ -2,10 +2,10 @@
 Scatterplot Matrix
 ==================
 
-_thumb: .5, .4
+_thumb: .5, .43
 """
 import seaborn as sns
-sns.set()
+sns.set(style="ticks")
 
 df = sns.load_dataset("iris")
 sns.pairplot(df, hue="species")
