@@ -2,35 +2,31 @@
 Discovering structure in heatmap data
 =====================================
 
-_thumb: .4, .2
+_thumb: .4, .25
 """
 import pandas as pd
 import seaborn as sns
-sns.set(font="monospace")
+sns.set()
 
 # Load the brain networks example dataset
 df = sns.load_dataset("brain_networks", header=[0, 1, 2], index_col=0)
 
 # Select a subset of the networks
-used_networks = [1, 5, 6, 7, 8, 11, 12, 13, 16, 17]
+used_networks = [1, 5, 6, 7, 8, 12, 13, 17]
 used_columns = (df.columns.get_level_values("network")
                           .astype(int)
                           .isin(used_networks))
 df = df.loc[:, used_columns]
 
-# Create a custom palette to identify the networks
-network_pal = sns.cubehelix_palette(len(used_networks),
-                                    light=.9, dark=.1, reverse=True,
-                                    start=1, rot=-2)
+# Create a categorical palette to identify the networks
+network_pal = sns.husl_palette(8, s=.45)
 network_lut = dict(zip(map(str, used_networks), network_pal))
 
 # Convert the palette to vectors that will be drawn on the side of the matrix
 networks = df.columns.get_level_values("network")
 network_colors = pd.Series(networks, index=df.columns).map(network_lut)
 
-# Create a custom colormap for the heatmap values
-cmap = sns.diverging_palette(h_neg=210, h_pos=350, s=90, l=30, as_cmap=True)
-
 # Draw the full plot
-sns.clustermap(df.corr(), row_colors=network_colors, linewidths=.5,
-               col_colors=network_colors, figsize=(13, 13), cmap=cmap)
+sns.clustermap(df.corr(), center=0, cmap="vlag",
+               row_colors=network_colors, col_colors=network_colors,
+               linewidths=.75, figsize=(13, 13))
