@@ -6,16 +6,15 @@ _orig_rc_params = mpl.rcParams.copy()
 from .rcmod import *
 from .utils import *
 from .palettes import *
+from .relational import *
 from .regression import *
 from .categorical import *
 from .distributions import *
-from .timeseries import *
 from .matrix import *
 from .miscplot import *
 from .axisgrid import *
 from .widgets import *
-from .xkcd_rgb import xkcd_rgb
-from .crayons import crayons
+from .colors import xkcd_rgb, crayons
 from . import cm
 
-__version__ = "0.8.0"
+__version__ = "0.10.0"
