@@ -4,6 +4,9 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 
+__all__ = ["palplot", "dogplot"]
+
+
 def palplot(pal, size=1):
     """Plot the values in a color palette as a horizontal array.
 
@@ -26,15 +29,19 @@ def palplot(pal, size=1):
     ax.set_yticklabels([])
 
 
-def puppyplot(grown_up=False):
-    """Plot today's daily puppy. Only works in the IPython notebook."""
-    from six.moves.urllib.request import urlopen
-    from bs4 import BeautifulSoup
-    from IPython.display import HTML
-    url = "http://www.dailypuppy.com"
-    if grown_up:
-        url += "/dogs"
-    html_doc = urlopen(url)
-    soup = BeautifulSoup(html_doc)
-    puppy = soup.find("div", {"class": "daily_puppy"})
-    return HTML(str(puppy.img))
+def dogplot(*_, **__):
+    """Who's a good boy?"""
+    try:
+        from urllib.request import urlopen
+    except ImportError:
+        from urllib2 import urlopen
+    from io import BytesIO
+
+    url = "https://github.com/mwaskom/seaborn-data/raw/master/png/img{}.png"
+    pic = np.random.randint(2, 7)
+    data = BytesIO(urlopen(url.format(pic)).read())
+    img = plt.imread(data)
+    f, ax = plt.subplots(figsize=(5, 5), dpi=100)
+    f.subplots_adjust(0, 0, 1, 1)
+    ax.imshow(img)
+    ax.set_axis_off()
