@@ -1,17 +1,26 @@
-"""Functions that alter the matplotlib rc dictionary on the fly."""
-import numpy as np
+"""Control plot style and scaling using the matplotlib rcParams interface."""
+from distutils.version import LooseVersion
+import functools
 import matplotlib as mpl
-
-from . import palettes
+import warnings
+from . import palettes, _orig_rc_params
 
 
-_style_keys = (
+mpl_ge_150 = LooseVersion(mpl.__version__) >= '1.5.0'
+mpl_ge_2 = LooseVersion(mpl.__version__) >= '2.0'
+
+
+__all__ = ["set", "reset_defaults", "reset_orig",
+           "axes_style", "set_style", "plotting_context", "set_context",
+           "set_palette"]
+
+
+_style_keys = [
 
     "axes.facecolor",
     "axes.edgecolor",
     "axes.grid",
     "axes.axisbelow",
-    "axes.linewidth",
     "axes.labelcolor",
 
     "figure.facecolor",
@@ -25,49 +34,64 @@ _style_keys = (
     "ytick.color",
     "xtick.direction",
     "ytick.direction",
-    "xtick.major.size",
-    "ytick.major.size",
-    "xtick.minor.size",
-    "ytick.minor.size",
-
-    "legend.frameon",
-    "legend.numpoints",
-    "legend.scatterpoints",
-
     "lines.solid_capstyle",
 
+    "patch.edgecolor",
+
     "image.cmap",
     "font.family",
     "font.sans-serif",
-    )
 
-_context_keys = (
-    "figure.figsize",
+    ]
 
+if mpl_ge_2:
+
+    _style_keys.extend([
+
+        "patch.force_edgecolor",
+
+        "xtick.bottom",
+        "xtick.top",
+        "ytick.left",
+        "ytick.right",
+
+        "axes.spines.left",
+        "axes.spines.bottom",
+        "axes.spines.right",
+        "axes.spines.top",
+
+    ])
+
+_context_keys = [
+
+    "font.size",
     "axes.labelsize",
     "axes.titlesize",
     "xtick.labelsize",
     "ytick.labelsize",
     "legend.fontsize",
 
+    "axes.linewidth",
     "grid.linewidth",
     "lines.linewidth",
-    "patch.linewidth",
     "lines.markersize",
-    "lines.markeredgewidth",
+    "patch.linewidth",
 
     "xtick.major.width",
     "ytick.major.width",
     "xtick.minor.width",
     "ytick.minor.width",
 
-    "xtick.major.pad",
-    "ytick.major.pad"
-    )
+    "xtick.major.size",
+    "ytick.major.size",
+    "xtick.minor.size",
+    "ytick.minor.size",
+
+    ]
 
 
 def set(context="notebook", style="darkgrid", palette="deep",
-        font="sans-serif", font_scale=1, color_codes=False, rc=None):
+        font="sans-serif", font_scale=1, color_codes=True, rc=None):
     """Set aesthetic parameters in one step.
 
     Each set of parameters can be set directly or temporarily, see the
@@ -107,35 +131,9 @@ def reset_defaults():
 
 def reset_orig():
     """Restore all RC params to original settings (respects custom rc)."""
-    mpl.rcParams.update(mpl.rcParamsOrig)
-
-
-class _AxesStyle(dict):
-    """Light wrapper on a dict to set style temporarily."""
-    def __enter__(self):
-        """Open the context."""
-        rc = mpl.rcParams
-        self._orig_style = {k: rc[k] for k in _style_keys}
-        set_style(self)
-        return self
-
-    def __exit__(self, *args):
-        """Close the context."""
-        set_style(self._orig_style)
-
-
-class _PlottingContext(dict):
-    """Light wrapper on a dict to set context temporarily."""
-    def __enter__(self):
-        """Open the context."""
-        rc = mpl.rcParams
-        self._orig_context = {k: rc[k] for k in _context_keys}
-        set_context(self)
-        return self
-
-    def __exit__(self, *args):
-        """Close the context."""
-        set_context(self._orig_context)
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', mpl.cbook.MatplotlibDeprecationWarning)
+        mpl.rcParams.update(_orig_rc_params)
 
 
 def axes_style(style=None, rc=None):
@@ -191,23 +189,34 @@ def axes_style(style=None, rc=None):
 
         # Common parameters
         style_dict = {
+
             "figure.facecolor": "white",
-            "text.color": dark_gray,
             "axes.labelcolor": dark_gray,
-            "legend.frameon": False,
-            "legend.numpoints": 1,
-            "legend.scatterpoints": 1,
+
             "xtick.direction": "out",
             "ytick.direction": "out",
             "xtick.color": dark_gray,
             "ytick.color": dark_gray,
+
             "axes.axisbelow": True,
-            "image.cmap": "Greys",
-            "font.family": ["sans-serif"],
-            "font.sans-serif": ["Arial", "Liberation Sans",
-                                "Bitstream Vera Sans", "sans-serif"],
             "grid.linestyle": "-",
+
+
+            "text.color": dark_gray,
+            "font.family": ["sans-serif"],
+            "font.sans-serif": ["Arial", "DejaVu Sans", "Liberation Sans",
+                                "Bitstream Vera Sans", "sans-serif"],
+
+
             "lines.solid_capstyle": "round",
+            "patch.edgecolor": "w",
+            "patch.force_edgecolor": True,
+
+            "image.cmap": "rocket",
+
+            "xtick.top": False,
+            "ytick.right": False,
+
             }
 
         # Set grid on or off
@@ -223,44 +232,62 @@ def axes_style(style=None, rc=None):
         # Set the color of the background, spines, and grids
         if style.startswith("dark"):
             style_dict.update({
+
                 "axes.facecolor": "#EAEAF2",
                 "axes.edgecolor": "white",
-                "axes.linewidth": 0,
                 "grid.color": "white",
+
+                "axes.spines.left": True,
+                "axes.spines.bottom": True,
+                "axes.spines.right": True,
+                "axes.spines.top": True,
+
                 })
 
         elif style == "whitegrid":
             style_dict.update({
+
                 "axes.facecolor": "white",
                 "axes.edgecolor": light_gray,
-                "axes.linewidth": 1,
                 "grid.color": light_gray,
+
+                "axes.spines.left": True,
+                "axes.spines.bottom": True,
+                "axes.spines.right": True,
+                "axes.spines.top": True,
+
                 })
 
         elif style in ["white", "ticks"]:
             style_dict.update({
+
                 "axes.facecolor": "white",
                 "axes.edgecolor": dark_gray,
-                "axes.linewidth": 1.25,
                 "grid.color": light_gray,
+
+                "axes.spines.left": True,
+                "axes.spines.bottom": True,
+                "axes.spines.right": True,
+                "axes.spines.top": True,
+
                 })
 
         # Show or hide the axes ticks
         if style == "ticks":
             style_dict.update({
-                "xtick.major.size": 6,
-                "ytick.major.size": 6,
-                "xtick.minor.size": 3,
-                "ytick.minor.size": 3,
+                "xtick.bottom": True,
+                "ytick.left": True,
                 })
         else:
             style_dict.update({
-                "xtick.major.size": 0,
-                "ytick.major.size": 0,
-                "xtick.minor.size": 0,
-                "ytick.minor.size": 0,
+                "xtick.bottom": False,
+                "ytick.left": False,
                 })
 
+    # Remove entries that are not defined in the base list of valid keys
+    # This lets us handle matplotlib <=/> 2.0
+    style_dict = {k: v for k, v in style_dict.items() if k in _style_keys}
+
     # Override these settings with the provided rc dictionary
     if rc is not None:
         rc = {k: v for k, v in rc.items() if k in _style_keys}
@@ -364,45 +391,41 @@ def plotting_context(context=None, font_scale=1, rc=None):
         # Set up dictionary of default parameters
         base_context = {
 
-            "figure.figsize": np.array([8, 5.5]),
-            "axes.labelsize": 11,
+            "font.size": 12,
+            "axes.labelsize": 12,
             "axes.titlesize": 12,
-            "xtick.labelsize": 10,
-            "ytick.labelsize": 10,
-            "legend.fontsize": 10,
+            "xtick.labelsize": 11,
+            "ytick.labelsize": 11,
+            "legend.fontsize": 11,
 
+            "axes.linewidth": 1.25,
             "grid.linewidth": 1,
-            "lines.linewidth": 1.75,
-            "patch.linewidth": .3,
-            "lines.markersize": 7,
-            "lines.markeredgewidth": 0,
+            "lines.linewidth": 1.5,
+            "lines.markersize": 6,
+            "patch.linewidth": 1,
 
-            "xtick.major.width": 1,
-            "ytick.major.width": 1,
-            "xtick.minor.width": .5,
-            "ytick.minor.width": .5,
+            "xtick.major.width": 1.25,
+            "ytick.major.width": 1.25,
+            "xtick.minor.width": 1,
+            "ytick.minor.width": 1,
+
+            "xtick.major.size": 6,
+            "ytick.major.size": 6,
+            "xtick.minor.size": 4,
+            "ytick.minor.size": 4,
 
-            "xtick.major.pad": 7,
-            "ytick.major.pad": 7,
             }
 
         # Scale all the parameters by the same factor depending on the context
-        scaling = dict(paper=.8, notebook=1, talk=1.3, poster=1.6)[context]
+        scaling = dict(paper=.8, notebook=1, talk=1.5, poster=2)[context]
         context_dict = {k: v * scaling for k, v in base_context.items()}
 
         # Now independently scale the fonts
         font_keys = ["axes.labelsize", "axes.titlesize", "legend.fontsize",
-                     "xtick.labelsize", "ytick.labelsize"]
+                     "xtick.labelsize", "ytick.labelsize", "font.size"]
         font_dict = {k: context_dict[k] * font_scale for k in font_keys}
         context_dict.update(font_dict)
 
-    # Implement hack workaround for matplotlib bug
-    # See https://github.com/mwaskom/seaborn/issues/344
-    # There is a bug in matplotlib 1.4.2 that makes points invisible when
-    # they don't have an edgewidth. It will supposedly be fixed in 1.4.3.
-    if mpl.__version__ == "1.4.2":
-        context_dict["lines.markeredgewidth"] = 0.01
-
     # Override these settings with the provided rc dictionary
     if rc is not None:
         rc = {k: v for k, v in rc.items() if k in _context_keys}
@@ -455,12 +478,41 @@ def set_context(context=None, font_scale=1, rc=None):
     mpl.rcParams.update(context_object)
 
 
+class _RCAesthetics(dict):
+    def __enter__(self):
+        rc = mpl.rcParams
+        self._orig = {k: rc[k] for k in self._keys}
+        self._set(self)
+
+    def __exit__(self, exc_type, exc_value, exc_tb):
+        self._set(self._orig)
+
+    def __call__(self, func):
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            with self:
+                return func(*args, **kwargs)
+        return wrapper
+
+
+class _AxesStyle(_RCAesthetics):
+    """Light wrapper on a dict to set style temporarily."""
+    _keys = _style_keys
+    _set = staticmethod(set_style)
+
+
+class _PlottingContext(_RCAesthetics):
+    """Light wrapper on a dict to set context temporarily."""
+    _keys = _context_keys
+    _set = staticmethod(set_context)
+
+
 def set_palette(palette, n_colors=None, desat=None, color_codes=False):
     """Set the matplotlib color cycle using a seaborn palette.
 
     Parameters
     ----------
-    palette : hls | husl | matplotlib colormap | seaborn color palette
+    palette : seaborn color paltte | matplotlib colormap | hls | husl
         Palette definition. Should be something that :func:`color_palette`
         can process.
     n_colors : int
@@ -488,7 +540,15 @@ def set_palette(palette, n_colors=None, desat=None, color_codes=False):
 
     """
     colors = palettes.color_palette(palette, n_colors, desat)
-    mpl.rcParams["axes.color_cycle"] = list(colors)
+    if mpl_ge_150:
+        from cycler import cycler
+        cyl = cycler('color', colors)
+        mpl.rcParams['axes.prop_cycle'] = cyl
+    else:
+        mpl.rcParams["axes.color_cycle"] = list(colors)
     mpl.rcParams["patch.facecolor"] = colors[0]
     if color_codes:
-        palettes.set_color_codes(palette)
+        try:
+            palettes.set_color_codes(palette)
+        except (ValueError, TypeError):
+            pass
