@@ -2,21 +2,26 @@ import colorsys
 import numpy as np
 import matplotlib as mpl
 
+import pytest
 import nose.tools as nt
 import numpy.testing as npt
+import matplotlib.pyplot as plt
 
-from .. import palettes, utils, rcmod, husl
-from ..xkcd_rgb import xkcd_rgb
-from ..crayons import crayons
+from .. import palettes, utils, rcmod
+from ..external import husl
+from ..colors import xkcd_rgb, crayons
+
+from distutils.version import LooseVersion
+mpl_ge_150 = LooseVersion(mpl.__version__) >= '1.5.0'
 
 
 class TestColorPalettes(object):
 
     def test_current_palette(self):
 
-        pal = palettes.color_palette(["red", "blue", "green"], 3)
-        rcmod.set_palette(pal, 3)
-        nt.assert_equal(pal, mpl.rcParams["axes.color_cycle"])
+        pal = palettes.color_palette(["red", "blue", "green"])
+        rcmod.set_palette(pal)
+        assert pal == utils.get_color_cycle()
         rcmod.set()
 
     def test_palette_context(self):
@@ -25,9 +30,9 @@ class TestColorPalettes(object):
         context_pal = palettes.color_palette("muted")
 
         with palettes.color_palette(context_pal):
-            nt.assert_equal(mpl.rcParams["axes.color_cycle"], context_pal)
+            nt.assert_equal(utils.get_color_cycle(), context_pal)
 
-        nt.assert_equal(mpl.rcParams["axes.color_cycle"], default_pal)
+        nt.assert_equal(utils.get_color_cycle(), default_pal)
 
     def test_big_palette_context(self):
 
@@ -36,19 +41,38 @@ class TestColorPalettes(object):
 
         rcmod.set_palette(original_pal)
         with palettes.color_palette(context_pal, 10):
-            nt.assert_equal(mpl.rcParams["axes.color_cycle"], context_pal)
+            nt.assert_equal(utils.get_color_cycle(), context_pal)
 
-        nt.assert_equal(mpl.rcParams["axes.color_cycle"], original_pal)
+        nt.assert_equal(utils.get_color_cycle(), original_pal)
 
         # Reset default
         rcmod.set()
 
+    def test_palette_size(self):
+
+        pal = palettes.color_palette("deep")
+        assert len(pal) == palettes.QUAL_PALETTE_SIZES["deep"]
+
+        pal = palettes.color_palette("pastel6")
+        assert len(pal) == palettes.QUAL_PALETTE_SIZES["pastel6"]
+
+        pal = palettes.color_palette("Set3")
+        assert len(pal) == palettes.QUAL_PALETTE_SIZES["Set3"]
+
+        pal = palettes.color_palette("husl")
+        assert len(pal) == 6
+
+        pal = palettes.color_palette("Greens")
+        assert len(pal) == 6
+
     def test_seaborn_palettes(self):
 
         pals = "deep", "muted", "pastel", "bright", "dark", "colorblind"
         for name in pals:
-            pal_out = palettes.color_palette(name)
-            nt.assert_equal(len(pal_out), 6)
+            full = palettes.color_palette(name, 10).as_hex()
+            short = palettes.color_palette(name + "6", 6).as_hex()
+            b, _, g, r, m, _, _, _, y, c = full
+            assert [b, g, r, m, y, c] == list(short)
 
     def test_hls_palette(self):
 
@@ -109,8 +133,8 @@ class TestColorPalettes(object):
 
     def test_palette_cycles(self):
 
-        deep = palettes.color_palette("deep")
-        double_deep = palettes.color_palette("deep", 12)
+        deep = palettes.color_palette("deep6")
+        double_deep = palettes.color_palette("deep6", 12)
         nt.assert_equal(double_deep, deep + deep)
 
     def test_hls_values(self):
@@ -120,8 +144,8 @@ class TestColorPalettes(object):
         pal2 = pal2[3:] + pal2[:3]
         npt.assert_array_almost_equal(pal1, pal2)
 
-        pal_dark = palettes.hls_palette(5, l=.2)
-        pal_bright = palettes.hls_palette(5, l=.8)
+        pal_dark = palettes.hls_palette(5, l=.2)  # noqa
+        pal_bright = palettes.hls_palette(5, l=.8)  # noqa
         npt.assert_array_less(list(map(sum, pal_dark)),
                               list(map(sum, pal_bright)))
 
@@ -137,8 +161,8 @@ class TestColorPalettes(object):
         pal2 = pal2[3:] + pal2[:3]
         npt.assert_array_almost_equal(pal1, pal2)
 
-        pal_dark = palettes.husl_palette(5, l=.2)
-        pal_bright = palettes.husl_palette(5, l=.8)
+        pal_dark = palettes.husl_palette(5, l=.2)  # noqa
+        pal_bright = palettes.husl_palette(5, l=.8)  # noqa
         npt.assert_array_less(list(map(sum, pal_dark)),
                               list(map(sum, pal_bright)))
 
@@ -161,7 +185,7 @@ class TestColorPalettes(object):
 
         pal_forward = palettes.mpl_palette("BuPu", 6)
         pal_reverse = palettes.mpl_palette("BuPu_r", 6)
-        nt.assert_equal(pal_forward, pal_reverse[::-1])
+        npt.assert_array_almost_equal(pal_forward, pal_reverse[::-1])
 
     def test_rgb_from_hls(self):
 
@@ -188,10 +212,10 @@ class TestColorPalettes(object):
 
         pal_forward = palettes.light_palette("red")
         pal_reverse = palettes.light_palette("red", reverse=True)
-        npt.assert_array_almost_equal(pal_forward, pal_reverse[::-1])
+        assert np.allclose(pal_forward, pal_reverse[::-1])
 
-        red = tuple(mpl.colors.colorConverter.to_rgba("red"))
-        nt.assert_equal(tuple(pal_forward[-1]), red)
+        red = mpl.colors.colorConverter.to_rgb("red")
+        nt.assert_equal(pal_forward[-1], red)
 
         pal_cmap = palettes.light_palette("blue", as_cmap=True)
         nt.assert_is_instance(pal_cmap, mpl.colors.LinearSegmentedColormap)
@@ -200,13 +224,35 @@ class TestColorPalettes(object):
 
         pal_forward = palettes.dark_palette("red")
         pal_reverse = palettes.dark_palette("red", reverse=True)
-        npt.assert_array_almost_equal(pal_forward, pal_reverse[::-1])
+        assert np.allclose(pal_forward, pal_reverse[::-1])
 
-        red = tuple(mpl.colors.colorConverter.to_rgba("red"))
-        nt.assert_equal(tuple(pal_forward[-1]), red)
+        red = mpl.colors.colorConverter.to_rgb("red")
+        assert pal_forward[-1] == red
 
         pal_cmap = palettes.dark_palette("blue", as_cmap=True)
-        nt.assert_is_instance(pal_cmap, mpl.colors.LinearSegmentedColormap)
+        assert isinstance(pal_cmap, mpl.colors.LinearSegmentedColormap)
+
+    def test_diverging_palette(self):
+
+        h_neg, h_pos = 100, 200
+        sat, lum = 70, 50
+        args = h_neg, h_pos, sat, lum
+
+        n = 12
+        pal = palettes.diverging_palette(*args,  n=n)
+        neg_pal = palettes.light_palette((h_neg, sat, lum), int(n // 2),
+                                         input="husl")
+        pos_pal = palettes.light_palette((h_pos, sat, lum), int(n // 2),
+                                         input="husl")
+        assert len(pal) == n
+        assert pal[0] == neg_pal[-1]
+        assert pal[-1] == pos_pal[-1]
+
+        pal_dark = palettes.diverging_palette(*args, n=n, center="dark")
+        assert np.mean(pal[int(n / 2)]) > np.mean(pal_dark[int(n / 2)])
+
+        pal_cmap = palettes.diverging_palette(*args, as_cmap=True)
+        assert isinstance(pal_cmap, mpl.colors.LinearSegmentedColormap)
 
     def test_blend_palette(self):
 
@@ -250,6 +296,27 @@ class TestColorPalettes(object):
         pal_reverse = cmap_rev(x[::-1]).tolist()
         nt.assert_list_equal(pal_forward, pal_reverse)
 
+    def test_cubehelix_code(self):
+
+        color_palette = palettes.color_palette
+        cubehelix_palette = palettes.cubehelix_palette
+
+        pal1 = color_palette("ch:", 8)
+        pal2 = color_palette(cubehelix_palette(8))
+        assert pal1 == pal2
+
+        pal1 = color_palette("ch:.5, -.25,hue = .5,light=.75", 8)
+        pal2 = color_palette(cubehelix_palette(8, .5, -.25, hue=.5, light=.75))
+        assert pal1 == pal2
+
+        pal1 = color_palette("ch:h=1,r=.5", 9)
+        pal2 = color_palette(cubehelix_palette(9, hue=1, rot=.5))
+        assert pal1 == pal2
+
+        pal1 = color_palette("ch:_r", 6)
+        pal2 = color_palette(cubehelix_palette(6, reverse=True))
+        assert pal1 == pal2
+
     def test_xkcd_palette(self):
 
         names = list(xkcd_rgb.keys())[10:15]
@@ -269,13 +336,16 @@ class TestColorPalettes(object):
     def test_color_codes(self):
 
         palettes.set_color_codes("deep")
-        colors = palettes.color_palette("deep") + [".1"]
+        colors = palettes.color_palette("deep6") + [".1"]
         for code, color in zip("bgrmyck", colors):
             rgb_want = mpl.colors.colorConverter.to_rgb(color)
             rgb_got = mpl.colors.colorConverter.to_rgb(code)
             nt.assert_equal(rgb_want, rgb_got)
         palettes.set_color_codes("reset")
 
+        with pytest.raises(ValueError):
+            palettes.set_color_codes("Set1")
+
     def test_as_hex(self):
 
         pal = palettes.color_palette("deep")
@@ -287,3 +357,12 @@ class TestColorPalettes(object):
         pal_in = palettes.color_palette("Set1", 10)
         pal_out = palettes.color_palette(pal_in)
         nt.assert_equal(pal_in, pal_out)
+
+    def test_get_color_cycle(self):
+
+        if mpl_ge_150:
+            colors = [(1., 0., 0.), (0, 1., 0.)]
+            prop_cycle = plt.cycler(color=colors)
+            with plt.rc_context({"axes.prop_cycle": prop_cycle}):
+                result = utils.get_color_cycle()
+                assert result == colors
