@@ -6,7 +6,7 @@ import matplotlib.pyplot as plt
 import nose.tools as nt
 import numpy.testing as npt
 
-from .. import rcmod
+from .. import rcmod, palettes, utils
 
 
 class RCParamTester(object):
@@ -20,10 +20,7 @@ class RCParamTester(object):
     def assert_rc_params(self, params):
 
         for k, v in params.items():
-            if k == "svg.embed_char_paths":
-                # This param causes test issues and is deprecated anyway
-                continue
-            elif isinstance(v, np.ndarray):
+            if isinstance(v, np.ndarray):
                 npt.assert_array_equal(mpl.rcParams[k], v)
             else:
                 nt.assert_equal((k, mpl.rcParams[k]), (k, v))
@@ -68,11 +65,18 @@ class TestAxesStyle(RCParamTester):
 
         rcmod.set_style("darkgrid")
         orig_params = rcmod.axes_style()
+        context_params = rcmod.axes_style("whitegrid")
+
         with rcmod.axes_style("whitegrid"):
-            context_params = rcmod.axes_style("whitegrid")
             self.assert_rc_params(context_params)
         self.assert_rc_params(orig_params)
 
+        @rcmod.axes_style("whitegrid")
+        def func():
+            self.assert_rc_params(context_params)
+        func()
+        self.assert_rc_params(orig_params)
+
     def test_style_context_independence(self):
 
         nt.assert_true(set(rcmod._style_keys) ^ set(rcmod._context_keys))
@@ -83,6 +87,29 @@ class TestAxesStyle(RCParamTester):
         nt.assert_equal(mpl.rcParams["lines.linewidth"], 4)
         rcmod.set()
 
+    def test_set_with_palette(self):
+
+        rcmod.reset_orig()
+
+        rcmod.set(palette="deep")
+        assert utils.get_color_cycle() == palettes.color_palette("deep", 10)
+        rcmod.reset_orig()
+
+        rcmod.set(palette="deep", color_codes=False)
+        assert utils.get_color_cycle() == palettes.color_palette("deep", 10)
+        rcmod.reset_orig()
+
+        pal = palettes.color_palette("deep")
+        rcmod.set(palette=pal)
+        assert utils.get_color_cycle() == palettes.color_palette("deep", 10)
+        rcmod.reset_orig()
+
+        rcmod.set(palette=pal, color_codes=False)
+        assert utils.get_color_cycle() == palettes.color_palette("deep", 10)
+        rcmod.reset_orig()
+
+        rcmod.set()
+
     def test_reset_defaults(self):
 
         # Changes to the rc parameters make this test hard to manage
@@ -133,7 +160,7 @@ class TestPlottingContext(RCParamTester):
         notebook_big = rcmod.plotting_context("notebook", 2)
 
         font_keys = ["axes.labelsize", "axes.titlesize", "legend.fontsize",
-                     "xtick.labelsize", "ytick.labelsize"]
+                     "xtick.labelsize", "ytick.labelsize", "font.size"]
 
         for k in font_keys:
             nt.assert_equal(notebook_ref[k] * 2, notebook_big[k])
@@ -158,11 +185,35 @@ class TestPlottingContext(RCParamTester):
 
         rcmod.set_context("notebook")
         orig_params = rcmod.plotting_context()
+        context_params = rcmod.plotting_context("paper")
+
         with rcmod.plotting_context("paper"):
-            context_params = rcmod.plotting_context("paper")
             self.assert_rc_params(context_params)
         self.assert_rc_params(orig_params)
 
+        @rcmod.plotting_context("paper")
+        def func():
+            self.assert_rc_params(context_params)
+        func()
+        self.assert_rc_params(orig_params)
+
+
+class TestPalette(object):
+
+    def test_set_palette(self):
+
+        rcmod.set_palette("deep")
+        assert utils.get_color_cycle() == palettes.color_palette("deep", 10)
+
+        rcmod.set_palette("pastel6")
+        assert utils.get_color_cycle() == palettes.color_palette("pastel6", 6)
+
+        rcmod.set_palette("dark", 4)
+        assert utils.get_color_cycle() == palettes.color_palette("dark", 4)
+
+        rcmod.set_palette("Set2", color_codes=True)
+        assert utils.get_color_cycle() == palettes.color_palette("Set2", 8)
+
 
 class TestFonts(object):
 
@@ -183,7 +234,6 @@ class TestFonts(object):
                 raise nose.SkipTest("Verdana font is not present")
         finally:
             rcmod.set()
-            plt.close("all")
 
     def test_set_serif_font(self):
 
@@ -196,7 +246,6 @@ class TestFonts(object):
                      mpl.rcParams["font.serif"])
 
         rcmod.set()
-        plt.close("all")
 
     def test_different_sans_serif(self):
 
@@ -204,8 +253,7 @@ class TestFonts(object):
             raise nose.SkipTest
 
         rcmod.set()
-        rcmod.set_style(rc={"font.sans-serif":
-                            ["Verdana"]})
+        rcmod.set_style(rc={"font.sans-serif": ["Verdana"]})
 
         _, ax = plt.subplots()
         ax.set_xlabel("foo")
@@ -220,7 +268,6 @@ class TestFonts(object):
                 raise nose.SkipTest("Verdana font is not present")
         finally:
             rcmod.set()
-            plt.close("all")
 
 
 def has_verdana():
@@ -231,7 +278,7 @@ def has_verdana():
     import matplotlib.font_manager as mplfm
     try:
         verdana_font = mplfm.findfont('Verdana', fallback_to_default=False)
-    except:
+    except:  # noqa
         # if https://github.com/matplotlib/matplotlib/pull/3435
         # gets accepted
         return False
@@ -239,7 +286,7 @@ def has_verdana():
     try:
         unlikely_font = mplfm.findfont("very_unlikely_to_exist1234",
                                        fallback_to_default=False)
-    except:
+    except:  # noqa
         # if matched verdana but not unlikely, Verdana must exist
         return True
     # otherwise -- if they match, must be the same default
