@@ -3,14 +3,15 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 import pandas as pd
 
+import pytest
 import nose.tools as nt
 import numpy.testing as npt
 try:
     import pandas.testing as pdt
 except ImportError:
     import pandas.util.testing as pdt
-from numpy.testing.decorators import skipif
 from nose import SkipTest
+from distutils.version import LooseVersion
 
 try:
     import statsmodels.regression.linear_model as smlm
@@ -18,14 +19,13 @@ try:
 except ImportError:
     _no_statsmodels = True
 
-from . import PlotTestCase
 from .. import regression as lm
 from ..palettes import color_palette
 
 rs = np.random.RandomState(0)
 
 
-class TestLinearPlotter(PlotTestCase):
+class TestLinearPlotter(object):
 
     rs = np.random.RandomState(77)
     df = pd.DataFrame(dict(x=rs.normal(size=60),
@@ -62,6 +62,16 @@ class TestLinearPlotter(PlotTestCase):
         npt.assert_array_equal(p.y, self.df.y)
         nt.assert_is(p.data, None)
 
+    def test_establish_variables_from_lists(self):
+
+        p = lm._LinearPlotter()
+        p.establish_variables(None,
+                              x=self.df.x.values.tolist(),
+                              y=self.df.y.values.tolist())
+        npt.assert_array_equal(p.x, self.df.x)
+        npt.assert_array_equal(p.y, self.df.y)
+        nt.assert_is(p.data, None)
+
     def test_establish_variables_from_mix(self):
 
         p = lm._LinearPlotter()
@@ -89,7 +99,7 @@ class TestLinearPlotter(PlotTestCase):
         pdt.assert_series_equal(p.y_na, self.df.y_na[mask])
 
 
-class TestRegressionPlotter(PlotTestCase):
+class TestRegressionPlotter(object):
 
     rs = np.random.RandomState(49)
 
@@ -138,6 +148,15 @@ class TestRegressionPlotter(PlotTestCase):
         npt.assert_array_equal(p.y, self.df.y + 1)
         pdt.assert_frame_equal(p.data, self.df)
 
+    def test_variables_must_be_1d(self):
+
+        array_2d = np.random.randn(20, 2)
+        array_1d = np.random.randn(20)
+        with pytest.raises(ValueError):
+            lm._RegressionPlotter(array_2d, array_1d)
+        with pytest.raises(ValueError):
+            lm._RegressionPlotter(array_1d, array_2d)
+
     def test_dropna(self):
 
         p = lm._RegressionPlotter("x", "y_na", data=self.df)
@@ -160,7 +179,7 @@ class TestRegressionPlotter(PlotTestCase):
         nt.assert_equal(p.ci, 95)
         nt.assert_equal(p.x_ci, "sd")
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_fast_regression(self):
 
         p = lm._RegressionPlotter("x", "y", data=self.df, n_boot=self.n_boot)
@@ -174,7 +193,7 @@ class TestRegressionPlotter(PlotTestCase):
         # Compare the vector of y_hat values
         npt.assert_array_almost_equal(yhat_fast, yhat_smod)
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_regress_poly(self):
 
         p = lm._RegressionPlotter("x", "y", data=self.df, n_boot=self.n_boot)
@@ -202,7 +221,7 @@ class TestRegressionPlotter(PlotTestCase):
         nt.assert_greater(yhat_log[20], yhat_lin[20])
         nt.assert_greater(yhat_lin[90], yhat_log[90])
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_regress_n_boot(self):
 
         p = lm._RegressionPlotter("x", "y", data=self.df, n_boot=self.n_boot)
@@ -219,7 +238,7 @@ class TestRegressionPlotter(PlotTestCase):
         _, boots_smod = p.fit_statsmodels(self.grid, smlm.OLS)
         npt.assert_equal(boots_smod.shape, (self.n_boot, self.grid.size))
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_regress_without_bootstrap(self):
 
         p = lm._RegressionPlotter("x", "y", data=self.df,
@@ -237,6 +256,18 @@ class TestRegressionPlotter(PlotTestCase):
         _, boots_smod = p.fit_statsmodels(self.grid, smlm.OLS)
         nt.assert_is(boots_smod, None)
 
+    def test_regress_bootstrap_seed(self):
+
+        seed = 200
+        p1 = lm._RegressionPlotter("x", "y", data=self.df,
+                                   n_boot=self.n_boot, seed=seed)
+        p2 = lm._RegressionPlotter("x", "y", data=self.df,
+                                   n_boot=self.n_boot, seed=seed)
+
+        _, boots1 = p1.fit_fast(self.grid)
+        _, boots2 = p2.fit_fast(self.grid)
+        npt.assert_array_equal(boots1, boots2)
+
     def test_numeric_bins(self):
 
         p = lm._RegressionPlotter(self.df.x, self.df.y)
@@ -295,15 +326,14 @@ class TestRegressionPlotter(PlotTestCase):
 
     def test_estimate_cis(self):
 
-        # set known good seed to avoid the test stochastically failing
-        np.random.seed(123)
+        seed = 123
 
         p = lm._RegressionPlotter(self.df.d, self.df.y,
-                                  x_estimator=np.mean, ci=95)
+                                  x_estimator=np.mean, ci=95, seed=seed)
         _, _, ci_big = p.estimate_data
 
         p = lm._RegressionPlotter(self.df.d, self.df.y,
-                                  x_estimator=np.mean, ci=50)
+                                  x_estimator=np.mean, ci=50, seed=seed)
         _, _, ci_wee = p.estimate_data
         npt.assert_array_less(np.diff(ci_wee), np.diff(ci_big))
 
@@ -315,14 +345,14 @@ class TestRegressionPlotter(PlotTestCase):
     def test_estimate_units(self):
 
         # Seed the RNG locally
-        np.random.seed(345)
+        seed = 345
 
         p = lm._RegressionPlotter("x", "y", data=self.df,
-                                  units="s", x_bins=3)
+                                  units="s", seed=seed, x_bins=3)
         _, _, ci_big = p.estimate_data
         ci_big = np.diff(ci_big, axis=1)
 
-        p = lm._RegressionPlotter("x", "y", data=self.df, x_bins=3)
+        p = lm._RegressionPlotter("x", "y", data=self.df, seed=seed, x_bins=3)
         _, _, ci_wee = p.estimate_data
         ci_wee = np.diff(ci_wee, axis=1)
 
@@ -345,7 +375,13 @@ class TestRegressionPlotter(PlotTestCase):
         _, r_partial = np.corrcoef(p.x, p.y)[0]
         nt.assert_less(r_partial, r_orig)
 
-    @skipif(_no_statsmodels)
+        x = pd.Series(x)
+        y = pd.Series(y)
+        p = lm._RegressionPlotter(y, z, x_partial=x, y_partial=x)
+        _, r_partial = np.corrcoef(p.x, p.y)[0]
+        nt.assert_less(r_partial, r_orig)
+
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_logistic_regression(self):
 
         p = lm._RegressionPlotter("x", "c", data=self.df,
@@ -354,16 +390,17 @@ class TestRegressionPlotter(PlotTestCase):
         npt.assert_array_less(yhat, 1)
         npt.assert_array_less(0, yhat)
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_logistic_perfect_separation(self):
 
         y = self.df.x > self.df.x.mean()
         p = lm._RegressionPlotter("x", y, data=self.df,
                                   logistic=True, n_boot=10)
-        _, yhat, _ = p.fit_regression(x_range=(-3, 3))
+        with np.errstate(all="ignore"):
+            _, yhat, _ = p.fit_regression(x_range=(-3, 3))
         nt.assert_true(np.isnan(yhat).all())
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_robust_regression(self):
 
         p_ols = lm._RegressionPlotter("x", "y", data=self.df,
@@ -376,7 +413,7 @@ class TestRegressionPlotter(PlotTestCase):
 
         nt.assert_equal(len(ols_yhat), len(robust_yhat))
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_lowess_regression(self):
 
         p = lm._RegressionPlotter("x", "y", data=self.df, lowess=True)
@@ -411,7 +448,7 @@ class TestRegressionPlotter(PlotTestCase):
         nt.assert_equal(grid.max(), self.df.x.max())
 
 
-class TestRegressionPlots(PlotTestCase):
+class TestRegressionPlots(object):
 
     rs = np.random.RandomState(56)
     df = pd.DataFrame(dict(x=rs.randn(90),
@@ -522,9 +559,8 @@ class TestRegressionPlots(PlotTestCase):
         g = lm.lmplot("x", "y", data=self.df, hue="h",
                       fit_reg=False, markers=["o", "+"])
         c = g.axes[0, 0].collections
-        nt.assert_equal(c[0].get_linewidths()[0], 0)
-        rclw = mpl.rcParams["lines.linewidth"]
-        nt.assert_equal(c[1].get_linewidths()[0], rclw)
+        nt.assert_equal(c[1].get_linewidths()[0],
+                        mpl.rcParams["lines.linewidth"])
 
     def test_lmplot_facets(self):
 
@@ -562,7 +598,7 @@ class TestRegressionPlots(PlotTestCase):
         npt.assert_array_equal(x, x_plot)
         npt.assert_array_almost_equal(resid, y_plot)
 
-    @skipif(_no_statsmodels)
+    @pytest.mark.skipif(_no_statsmodels, reason="no statsmodels")
     def test_residplot_lowess(self):
 
         ax = lm.residplot("x", "y", self.df, lowess=True)
@@ -578,3 +614,14 @@ class TestRegressionPlots(PlotTestCase):
         color = ax.collections[0].get_facecolors()
         npt.assert_almost_equal(color[0, :3],
                                 (1, 0, 0))
+
+    @pytest.mark.skipif(LooseVersion(mpl.__version__) < "2.0",
+                        reason="not supported on old matplotlib")
+    def test_regplot_xlim(self):
+
+        f, ax = plt.subplots()
+        x, y1, y2 = np.random.randn(3, 50)
+        lm.regplot(x, y1, truncate=False)
+        lm.regplot(x, y2, truncate=False)
+        line1, line2 = ax.lines
+        assert np.array_equal(line1.get_xdata(), line2.get_xdata())
