@@ -1,5 +1,4 @@
 """Tests for plotting utilities."""
-import warnings
 import tempfile
 import shutil
 
@@ -17,19 +16,19 @@ except ImportError:
     import pandas.util.testing as pdt
 
 from distutils.version import LooseVersion
-pandas_has_categoricals = LooseVersion(pd.__version__) >= "0.15"
-
 
 try:
     from bs4 import BeautifulSoup
 except ImportError:
     BeautifulSoup = None
 
-from . import PlotTestCase
 from .. import utils, rcmod
 from ..utils import get_dataset_names, load_dataset, _network
 
 
+pandas_has_categoricals = LooseVersion(pd.__version__) >= "0.15"
+
+
 a_norm = np.random.randn(100)
 
 
@@ -121,7 +120,7 @@ def test_str_to_utf8():
     assert_equal(type(u), type(u"\u01ff\u02ff"))
 
 
-class TestSpineUtils(PlotTestCase):
+class TestSpineUtils(object):
 
     sides = ["left", "right", "bottom", "top"]
     outer_sides = ["top", "right"]
@@ -234,6 +233,40 @@ class TestSpineUtils(PlotTestCase):
         utils.despine(trim=True)
         nt.assert_equal(ax.get_yticks().size, 0)
 
+    def test_despine_moved_ticks(self):
+
+        f, ax = plt.subplots()
+        for t in ax.yaxis.majorTicks:
+            t.tick1line.set_visible(True)
+        utils.despine(ax=ax, left=True, right=False)
+        for y in ax.yaxis.majorTicks:
+            assert t.tick2line.get_visible()
+        plt.close(f)
+
+        f, ax = plt.subplots()
+        for t in ax.yaxis.majorTicks:
+            t.tick1line.set_visible(False)
+        utils.despine(ax=ax, left=True, right=False)
+        for y in ax.yaxis.majorTicks:
+            assert not t.tick2line.get_visible()
+        plt.close(f)
+
+        f, ax = plt.subplots()
+        for t in ax.xaxis.majorTicks:
+            t.tick1line.set_visible(True)
+        utils.despine(ax=ax, bottom=True, top=False)
+        for y in ax.xaxis.majorTicks:
+            assert t.tick2line.get_visible()
+        plt.close(f)
+
+        f, ax = plt.subplots()
+        for t in ax.xaxis.majorTicks:
+            t.tick1line.set_visible(False)
+        utils.despine(ax=ax, bottom=True, top=False)
+        for y in ax.xaxis.majorTicks:
+            assert not t.tick2line.get_visible()
+        plt.close(f)
+
 
 def test_ticklabels_overlap():
 
@@ -302,6 +335,39 @@ def test_categorical_order():
     nt.assert_equal(out, ["a", "c", "b", "d"])
 
 
+def test_locator_to_legend_entries():
+
+    locator = mpl.ticker.MaxNLocator(nbins=3)
+    limits = (0.09, 0.4)
+    levels, str_levels = utils.locator_to_legend_entries(
+        locator, limits, float
+    )
+    assert str_levels == ["0.00", "0.15", "0.30", "0.45"]
+
+    limits = (0.8, 0.9)
+    levels, str_levels = utils.locator_to_legend_entries(
+        locator, limits, float
+    )
+    assert str_levels == ["0.80", "0.84", "0.88", "0.92"]
+
+    limits = (1, 6)
+    levels, str_levels = utils.locator_to_legend_entries(locator, limits, int)
+    assert str_levels == ["0", "2", "4", "6"]
+
+    locator = mpl.ticker.LogLocator(numticks=3)
+    limits = (5, 1425)
+    levels, str_levels = utils.locator_to_legend_entries(locator, limits, int)
+    if LooseVersion(mpl.__version__) >= "3.1":
+        assert str_levels == ['0', '1', '100', '10000', '1e+06']
+
+    limits = (0.00003, 0.02)
+    levels, str_levels = utils.locator_to_legend_entries(
+        locator, limits, float
+    )
+    if LooseVersion(mpl.__version__) >= "3.1":
+        assert str_levels == ['1e-07', '1e-05', '1e-03', '1e-01', '10']
+
+
 if LooseVersion(pd.__version__) >= "0.15":
 
     def check_load_dataset(name):
@@ -374,3 +440,14 @@ def test_relative_luminance():
 
     for lum1, lum2 in zip(lums1, lums2):
         nose.tools.assert_almost_equal(lum1, lum2)
+
+
+def test_remove_na():
+
+    a_array = np.array([1, 2, np.nan, 3])
+    a_array_rm = utils.remove_na(a_array)
+    npt.assert_array_equal(a_array_rm, np.array([1, 2, 3]))
+
+    a_series = pd.Series([1, 2, np.nan, 3])
+    a_series_rm = utils.remove_na(a_series)
+    pdt.assert_series_equal(a_series_rm, pd.Series([1., 2, 3], [0, 1, 3]))
