@@ -1,7 +1,6 @@
 """Small plotting-related utility functions."""
 from __future__ import print_function, division
 import colorsys
-import warnings
 import os
 
 import numpy as np
@@ -11,17 +10,39 @@ import matplotlib as mpl
 import matplotlib.colors as mplcol
 import matplotlib.pyplot as plt
 
-from distutils.version import LooseVersion
-pandas_has_categoricals = LooseVersion(pd.__version__) >= "0.15"
-mpl_ge_150 = LooseVersion(mpl.__version__) >= "1.5.0"
-from .external.six.moves.urllib.request import urlopen, urlretrieve
-from .external.six.moves.http_client import HTTPException
+from urllib.request import urlopen, urlretrieve
+from http.client import HTTPException
 
 
 __all__ = ["desaturate", "saturate", "set_hls_values",
            "despine", "get_dataset_names", "load_dataset"]
 
 
+def remove_na(arr):
+    """Helper method for removing NA values from array-like.
+
+    Parameters
+    ----------
+    arr : array-like
+        The array-like from which to remove NA values.
+
+    Returns
+    -------
+    clean_arr : array-like
+        The original array with NA values removed.
+
+    """
+    return arr[pd.notnull(arr)]
+
+
+def sort_df(df, *args, **kwargs):
+    """Wrapper to handle different pandas sorting API pre/post 0.17."""
+    try:
+        return df.sort_values(*args, **kwargs)
+    except AttributeError:
+        return df.sort(*args, **kwargs)
+
+
 def ci_to_errsize(cis, heights):
     """Convert intervals to error arguments relative to plot heights.
 
@@ -130,7 +151,7 @@ def saturate(color):
     return set_hls_values(color, s=1)
 
 
-def set_hls_values(color, h=None, l=None, s=None):
+def set_hls_values(color, h=None, l=None, s=None):  # noqa
     """Independently manipulate the h, l, or s channels of a color.
 
     Parameters
@@ -208,15 +229,36 @@ def despine(fig=None, ax=None, top=True, right=True, left=False,
                     val = offset
                 _set_spine_position(ax_i.spines[side], ('outward', val))
 
-        # Set the ticks appropriately
-        if bottom:
-            ax_i.xaxis.tick_top()
-        if top:
-            ax_i.xaxis.tick_bottom()
-        if left:
-            ax_i.yaxis.tick_right()
-        if right:
-            ax_i.yaxis.tick_left()
+        # Potentially move the ticks
+        if left and not right:
+            maj_on = any(
+                t.tick1line.get_visible()
+                for t in ax_i.yaxis.majorTicks
+            )
+            min_on = any(
+                t.tick1line.get_visible()
+                for t in ax_i.yaxis.minorTicks
+            )
+            ax_i.yaxis.set_ticks_position("right")
+            for t in ax_i.yaxis.majorTicks:
+                t.tick2line.set_visible(maj_on)
+            for t in ax_i.yaxis.minorTicks:
+                t.tick2line.set_visible(min_on)
+
+        if bottom and not top:
+            maj_on = any(
+                t.tick1line.get_visible()
+                for t in ax_i.xaxis.majorTicks
+            )
+            min_on = any(
+                t.tick1line.get_visible()
+                for t in ax_i.xaxis.minorTicks
+            )
+            ax_i.xaxis.set_ticks_position("top")
+            for t in ax_i.xaxis.majorTicks:
+                t.tick2line.set_visible(maj_on)
+            for t in ax_i.xaxis.minorTicks:
+                t.tick2line.set_visible(min_on)
 
         if trim:
             # clip off the parts of the spines that extend past major ticks
@@ -398,9 +440,6 @@ def load_dataset(name, cache=True, data_home=None, **kws):
     if df.iloc[-1].isnull().all():
         df = df.iloc[:-1]
 
-    if not pandas_has_categoricals:
-        return df
-
     # Set some columns as a categorical type with ordered levels
 
     if name == "tips":
@@ -504,16 +543,42 @@ def categorical_order(values, order=None):
     return list(order)
 
 
+def locator_to_legend_entries(locator, limits, dtype):
+    """Return levels and formatted levels for brief numeric legends."""
+    raw_levels = locator.tick_values(*limits).astype(dtype)
+
+    class dummy_axis:
+        def get_view_interval(self):
+            return limits
+
+    if isinstance(locator, mpl.ticker.LogLocator):
+        formatter = mpl.ticker.LogFormatter()
+    else:
+        formatter = mpl.ticker.ScalarFormatter()
+    formatter.axis = dummy_axis()
+
+    # TODO: The following two lines should be replaced
+    # once pinned matplotlib>=3.1.0 with:
+    # formatted_levels = formatter.format_ticks(raw_levels)
+    formatter.set_locs(raw_levels)
+    formatted_levels = [formatter(x) for x in raw_levels]
+
+    return raw_levels, formatted_levels
+
+
 def get_color_cycle():
-    if mpl_ge_150:
+    """Return the list of colors in the current matplotlib color cycle."""
+    try:
         cyl = mpl.rcParams['axes.prop_cycle']
-        # matplotlib 1.5 verifies that axes.prop_cycle *is* a cycler
-        # but no garuantee that there's a `color` key.
-        # so users could have a custom rcParmas w/ no color...
         try:
+            # matplotlib 1.5 verifies that axes.prop_cycle *is* a cycler
+            # but no garuantee that there's a `color` key.
+            # so users could have a custom rcParmas w/ no color...
             return [x['color'] for x in cyl]
         except KeyError:
-            pass  # just return axes.color style below
+            pass
+    except KeyError:
+        pass
     return mpl.rcParams['axes.color_cycle']
 
 
@@ -589,7 +654,7 @@ def to_utf8(obj):
             return obj.__str__()
 
 
-def _network(t=None, url='http://google.com'):
+def _network(t=None, url='https://google.com'):
     """
     Decorator that will skip a test if `url` is unreachable.
 
